@@ -2,13 +2,14 @@ package upgrade
 
 import (
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
 	"os"
 	"path/filepath"
 )
 
-func install(tag string) error {
+func install(cfg *Config) error {
 	setState(validating)
 
 	executable, err := os.Executable()
@@ -16,24 +17,24 @@ func install(tag string) error {
 		return err
 	}
 
-	setState(downloading)
-
-	data, err := downloadAndVerify(tag)
-	if err != nil {
-		return err
-	}
-
-	setState(installing)
-
 	targetDir := filepath.Dir(executable)
 	fileName := filepath.Base(executable)
 
 	newPath := filepath.Join(targetDir, fmt.Sprintf(".%s.new", fileName))
 	fp, err := os.OpenFile(newPath, os.O_CREATE|os.O_WRONLY|os.O_TRUNC, 0775)
+	if err != nil {
+		return errors.New("we do not have permissions to update")
+	}
+
+	setState(downloading)
+
+	data, err := downloadAndVerify(cfg)
 	if err != nil {
 		return err
 	}
 
+	setState(installing)
+
 	_, err = io.Copy(fp, bytes.NewReader(data))
 	// windows will have a lock when we do not close the file
 	fp.Close()
@@ -70,7 +71,5 @@ func install(tag string) error {
 		_ = hideFile(oldPath)
 	}
 
-	updateRegistry(tag, executable)
-
 	return nil
 }
